@@ -12,8 +12,12 @@
 
 #include <QHeaderView>
 
+#include <ki18n_version.h>
 #include <KSharedConfig>
 #include <KConfigGroup>
+#include <KLazyLocalizedString>
+#undef I18NC_NOOP
+#define I18NC_NOOP kli18nc
 
 static const int WarningNameRole = Qt::UserRole + 100;
 
@@ -133,8 +137,7 @@ void Warnings_Config::loadSettings()
     static const struct DefinitionItem
     {
         const char *flagName;
-        const char *context;
-        const char *message;
+        const KLazyLocalizedString message;
     } warningDialogDefinitions[] = {
         { "Invitation",                                                                                 I18NC_NOOP("@item:inlistbox Checkbox item, determines whether warning dialog is shown; concludes sentence \"Show a warning dialog when...\"",
           "... a channel invitation is received"
@@ -205,11 +208,10 @@ void Warnings_Config::loadSettings()
 
     for (const auto& warningDialogDefinition : warningDialogDefinitions) {
         const QLatin1String flagName(warningDialogDefinition.flagName);
-        const char * const message(warningDialogDefinition.message);
-        const char * const ctx(warningDialogDefinition.context);
+        const QString message = warningDialogDefinition.message.toString();
 
         auto *item = new QTreeWidgetItem(dialogListView);
-        item->setText(0, i18nc(ctx, message));
+        item->setText(0, message);
         item->setFlags(item->flags() | Qt::ItemIsUserCheckable);
         item->setData(0, WarningNameRole, flagName);
 
