@@ -1,12 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2009 Bernd Buschinski <b.buschinski@web.de>
+    SPDX-FileCopyrightText: 2009 Bernd Buschinski <b.buschinski@web.de>
 */
 
 #ifndef WHITEBOARD_H
@@ -63,9 +58,9 @@ namespace Konversation
                 void rawWhiteBoardCommand(const QString& command);
 
             private:
-                inline QColor parseColor(const QString& colorString, bool* ok = 0);
-                inline QString colorToString(const QColor& color);
-                inline int fontToStyle(const QFont& font);
+                static QColor parseColor(const QString& colorString, bool* ok = nullptr);
+                static QString colorToString(const QColor& color);
+                static int fontToStyle(const QFont& font);
 
                 inline void emitDRCommand(WhiteBoardGlobals::WhiteBoardTool tool, int lineWidth,
                                          const QColor& penColor, const QColor& brushColor,
@@ -76,8 +71,11 @@ namespace Konversation
                 inline void emitDo(const QString& doString);
                 inline void emitDont(const QString& doNotString);
 
+            private:
                 WhiteBoardToolBar* m_toolbar;
                 WhiteBoardPaintArea* m_paintArea;
+
+                Q_DISABLE_COPY(WhiteBoard)
         };
     }
 }
